@@ -69,6 +69,9 @@ static const char *browsers[][2] = {
   {"Edg", "Edge"},
   {"Edge", "Edge"},
 
+  /* Surf Browser */
+  {"Surf", "Surf"},
+
   /* Opera */
   {"Opera Mini", "Opera"},
   {"Opera Mobi", "Opera"},
@@ -114,6 +117,11 @@ static const char *browsers[][2] = {
   {"MicroMessenger", "Others"},
   {"Apache", "Others"},
   {"JOSM", "Others"},
+  {"pacman", "Others"},
+  {"Pamac", "Others"},
+  {"libwww-perl", "Others"},
+  {"python-requests", "Others"},
+  {"PackageKit", "Others"},
 
   /* Feed-reader-as-a-service */
   {"AppleNewsBot", "Feeds"},
@@ -123,9 +131,11 @@ static const char *browsers[][2] = {
   {"FeedHQ", "Feeds"},
   {"Feedly", "Feeds"},
   {"Flipboard", "Feeds"},
+  {"inoreader.com", "Feeds"},
   {"Netvibes", "Feeds"},
   {"NewsBlur", "Feeds"},
   {"PinRSS", "Feeds"},
+  {"theoldreader.com", "Feeds"},
   {"WordPress.com Reader", "Feeds"},
   {"YandexBlogs", "Feeds"},
 
@@ -189,6 +199,33 @@ static const char *browsers[][2] = {
   {"Microsoft-WebDAV", "Crawlers"},
   {"DuckDuckGo-Favicons-Bot", "Crawlers"},
   {"bingbot", "Crawlers"},
+  {"PetalBot", "Crawlers"},
+  {"Discordbot", "Crawlers"},
+  {"ZoominfoBot", "Crawlers"},
+  {"Googlebot", "Crawlers"},
+  {"DotBot", "Crawlers"},
+  {"AhrefsBot", "Crawlers"},
+  {"SemrushBot", "Crawlers"},
+  {"Adsbot", "Crawlers"},
+  {"BLEXBot", "Crawlers"},
+  {"NetcraftSurveyAgent", "Crawlers"},
+  {"Netcraft Web Server Survey", "Crawlers"},
+  {"masscan", "Crawlers"},
+  {"MJ12bot", "Crawlers"},
+  {"Pandalytics", "Crawlers"},
+  {"YandexBot", "Crawlers"},
+  {"Nimbostratus-Bot", "Crawlers"},
+  {"HTTP Banner Detection", "Crawlers"},
+  {"Hakai", "Crawlers"},
+  {"WinHttp.WinHttpRequest.5", "Crawlers"},
+  {"NetSystemsResearch", "Crawlers"},
+  {"Nextcloud Server Crawler", "Crawlers"},
+  {"CFNetwork", "Crawlers"},
+  {"GoScraper", "Crawlers"},
+  {"Googlebot-Image", "Crawlers"},
+  {"ZmEu", "Crawlers"},
+  {"DowntimeDetector", "Crawlers"},
+
 
   /* Podcast fetchers */
   {"Downcast", "Podcasts"},
@@ -202,6 +239,7 @@ static const char *browsers[][2] = {
   /* Feed reader clients */
   {"Akregator", "Feeds"},
   {"Apple-PubSub", "Feeds"},
+  {"BTWebClient", "Feeds"},
   {"com.apple.Safari.WebFeedParser", "Feeds"},
   {"FeedDemon", "Feeds"},
   {"Feedy", "Feeds"},
