@@ -43,7 +43,7 @@
 #define __attribute__(x) /**/
 #endif
 #define GO_UNUSED __attribute__((unused))
-#define GO_VERSION 		"1.4.1"
+#define GO_VERSION 		"1.4.2"
 #define GO_WEBSITE 		"https://goaccess.io/"
 extern struct tm now_tm;
 
@@ -52,9 +52,9 @@ extern struct tm now_tm;
 
 /* total number of modules */
 #ifdef HAVE_GEOLOCATION
-#define TOTAL_MODULES    16
+#define TOTAL_MODULES    18
 #else
-#define TOTAL_MODULES    15
+#define TOTAL_MODULES    17
 #endif
 
 /* maximum number of items within a panel */
@@ -108,6 +108,8 @@ typedef enum MODULES {
 #ifdef HAVE_GEOLOCATION
   GEO_LOCATION,
 #endif
+  MIME_TYPE,
+  TLS_TYPE,
 } GModule;
 
 /* Metric totals. These are metrics that have a percent value and are
