@@ -3271,9 +3271,13 @@ get_str_raw_data (GModule module) {
 GRawData *
 parse_raw_data (GModule module) {
   GRawData *raw_data = NULL;
+
+#ifdef _DEBUG
   clock_t begin = clock ();
   double taken;
   char *modstr = NULL;
+  LOG_DEBUG (("== parse_raw_data ==\n"));
+#endif
 
   switch (module) {
   case VISITORS:
@@ -3287,10 +3291,12 @@ parse_raw_data (GModule module) {
       sort_raw_num_data (raw_data, raw_data->idx);
   }
 
+#ifdef _DEBUG
   modstr = get_module_str (module);
   taken = (double) (clock () - begin) / CLOCKS_PER_SEC;
-  LOG_DEBUG (("== %s\t\t\t%f\n", modstr, taken));
+  LOG_DEBUG (("== %-30s%f\n\n", modstr, taken));
   free (modstr);
+#endif
 
   return raw_data;
 }
