@@ -80,6 +80,10 @@ const int sort_choices[][SORT_MAX_OPTS] = {
   /* GEO_LOCATION */
   {SORT_BY_HITS, SORT_BY_VISITORS, SORT_BY_DATA, SORT_BY_BW, SORT_BY_AVGTS, SORT_BY_CUMTS, SORT_BY_MAXTS, -1},
 #endif
+  /* MIME_TYPE */
+  {SORT_BY_HITS, SORT_BY_DATA, SORT_BY_BW, SORT_BY_AVGTS, SORT_BY_CUMTS, SORT_BY_MAXTS, -1},
+  /* TLS_TYPE */
+  {SORT_BY_HITS, SORT_BY_DATA, SORT_BY_VISITORS, SORT_BY_BW, -1},
 };
 
 static GEnum FIELD[] = {
@@ -118,6 +122,8 @@ GSort module_sort[TOTAL_MODULES] = {
 #ifdef HAVE_GEOLOCATION
   {GEO_LOCATION        , SORT_BY_HITS , SORT_DESC } ,
 #endif
+  {MIME_TYPE           , SORT_BY_HITS , SORT_DESC } ,
+  {TLS_TYPE            , SORT_BY_VISITORS , SORT_DESC } ,
 };
 /* *INDENT-ON* */
 
