@@ -87,6 +87,8 @@ static GOutput outputting[] = {
 #ifdef HAVE_GEOLOCATION
   {GEO_LOCATION    , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
 #endif
+  {MIME_TYPE       , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
+  {TLS_TYPE        , 1 , 1 , 1 , 1 , 1 , 1 , 1 , 0 , 0 , 1 , 0 , 0} ,
 };
 /* *INDENT-ON* */
 
@@ -271,6 +273,8 @@ module_to_label (GModule module) {
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_LABEL,
 #endif
+    MIME_TYPE_LABEL,
+    TLS_TYPE_LABEL,
   };
 
   return _(modules[module]);
@@ -300,6 +304,8 @@ module_to_id (GModule module) {
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_ID,
 #endif
+    MIME_TYPE_ID,
+    TLS_TYPE_ID,
   };
 
   return _(modules[module]);
@@ -329,6 +335,8 @@ module_to_head (GModule module) {
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_HEAD,
 #endif
+    MIME_TYPE_HEAD,
+    TLS_TYPE_HEAD,
   };
 
   if (!conf.ignore_crawlers)
@@ -362,6 +370,8 @@ module_to_desc (GModule module) {
 #ifdef HAVE_GEOLOCATION
     GEO_LOCATION_DESC,
 #endif
+    MIME_TYPE_DESC,
+    TLS_TYPE_DESC,
   };
 
   return _(modules[module]);
@@ -962,6 +972,7 @@ ui_spinner (void *ptr_data) {
 
   static char const spin_chars[] = "/-\\|";
   char buf[SPIN_LBL];
+  const char *fn = NULL;
   int i = 0;
   long long tdiff = 0, psec = 0;
   time_t begin;
@@ -983,9 +994,10 @@ ui_spinner (void *ptr_data) {
     if (conf.no_progress) {
       snprintf (buf, sizeof buf, SPIN_FMT, sp->label);
     } else {
+      fn = *sp->filename ? *sp->filename : "restoring";
       tdiff = (long long) (time (NULL) - begin);
-      psec = tdiff >= 1 ? *(sp->processed) / tdiff : 0;
-      snprintf (buf, sizeof buf, SPIN_FMTM, sp->label, *(sp->processed), psec);
+      psec = tdiff >= 1 ? **(sp->processed) / tdiff : 0;
+      snprintf (buf, sizeof buf, SPIN_FMTM, sp->label, fn, **(sp->processed), psec);
     }
     setlocale (LC_NUMERIC, "POSIX");
 
@@ -999,7 +1011,7 @@ ui_spinner (void *ptr_data) {
       wrefresh (sp->win);
     } else if (!conf.no_progress) {
       /* STDOUT */
-      fprintf (stderr, "%s\r", buf);
+      fprintf (stderr, " %s\r", buf);
     }
 
     pthread_mutex_unlock (&sp->mutex);
@@ -1227,7 +1239,7 @@ load_confdlg_error (WINDOW * parent_win, char **errors, int nerrors) {
  * On error, or if the selected format is invalid, 1 is returned.
  * On success, 0 is returned. */
 int
-render_confdlg (GLog * glog, GSpinner * spinner) {
+render_confdlg (Logs * logs, GSpinner * spinner) {
   GMenu *menu;
   WINDOW *win;
 
@@ -1405,13 +1417,13 @@ render_confdlg (GLog * glog, GSpinner * spinner) {
         int nerrors = 0;
 
         /* test log against selected settings */
-        if ((errors = test_format (glog, &nerrors))) {
+        if ((errors = test_format (logs, &nerrors))) {
           invalid = 1;
           load_confdlg_error (win, errors, nerrors);
         }
         /* valid data, reset glog & start parsing */
         else {
-          reset_struct (glog);
+          reset_struct (logs);
           /* start spinner thread */
           spinner->win = win;
           spinner->y = 3;
