@@ -57,8 +57,8 @@
 
 /* Spinner Label Format */
 #define SPIN_FMT "%s"
-#define SPIN_FMTM "%s [%'u] [%'lld/s]"
-#define SPIN_LBL 50     /* max length of the progress spinner */
+#define SPIN_FMTM "[%s %s] {%'"PRIu64"} @ {%'lld/s}"
+#define SPIN_LBL 256    /* max length of the progress spinner */
 
 #define SPIN_UPDATE_INTERVAL 100000     // in microseconds
 
@@ -81,6 +81,9 @@
 #define STATUS_CODES_ID    "status_codes"
 #define GENER_ID           "general"
 
+#define MIME_TYPE_ID       "mime_type"
+#define TLS_TYPE_ID        "tls_type"
+
 /* Overall Statistics CSV/JSON Keys */
 #define OVERALL_STARTDATE "start_date"
 #define OVERALL_ENDDATE   "end_date"
@@ -189,7 +192,8 @@ typedef struct GSpinner_ {
   int y;
   pthread_mutex_t mutex;
   pthread_t thread;
-  unsigned int *processed;
+  uint64_t **processed;
+  char **filename;
   WINDOW *win;
   enum {
     SPN_RUN,
@@ -227,7 +231,7 @@ const char *module_to_head (GModule module);
 const char *module_to_id (GModule module);
 const char *module_to_label (GModule module);
 int get_start_end_parsing_dates (char **start, char **end, const char *f);
-int render_confdlg (GLog * glog, GSpinner * spinner);
+int render_confdlg (Logs * logs, GSpinner * spinner);
 void close_win (WINDOW * w);
 GAgents *load_host_agents (const char *addr);
 void display_general (WINDOW * win, GHolder *h);
